@@ -39,11 +39,18 @@
 #include <limits.h>
 #include <ctype.h>
 
+#if defined(CPU_COUNT) && (CPU_COUNT+0) < 2
+#undef CPU_COUNT
+#endif
+#if !defined(CPU_COUNT)
+#define CPU_COUNT 2
+#endif
+
 /**
  * Number of threads to run in the thread pool.  Should (roughly) match
  * the number of cores on your system.
  */
-#define NUMBER_OF_THREADS 8
+#define NUMBER_OF_THREADS CPU_COUNT
 
 /**
  * How many bytes of a file do we give to libmagic to determine the mime type?
