@@ -24,7 +24,7 @@
  * @author Tatsuhiro Tsujikawa
  */
  
- //TODO child exits with ret val 1 sometimes
+//TODO child exits with ret val 1 sometimes
  
 #include "platform.h"
 #include "microspdy.h"
@@ -44,12 +44,17 @@ pid_t child;
 int
 spdylay_printf(const char *format, ...)
 {
+  (void)format;
+  
 	return 0;
 }
 
 int
 spdylay_fprintf(FILE *stream, const char *format, ...)
 {
+  (void)stream;
+  (void)format;
+  
 	return 0;
 }
  
@@ -215,6 +220,9 @@ static ssize_t send_callback(spdylay_session *session,
                              const uint8_t *data, size_t length, int flags,
                              void *user_data)
 {
+  (void)session;
+  (void)flags;
+  
   struct Connection *connection;
   ssize_t rv;
   connection = (struct Connection*)user_data;
@@ -244,6 +252,9 @@ static ssize_t recv_callback(spdylay_session *session,
                              uint8_t *buf, size_t length, int flags,
                              void *user_data)
 {
+  (void)session;
+  (void)flags;
+  
   struct Connection *connection;
   ssize_t rv;
   connection = (struct Connection*)user_data;
@@ -276,6 +287,8 @@ static void before_ctrl_send_callback(spdylay_session *session,
                                       spdylay_frame *frame,
                                       void *user_data)
 {
+  (void)user_data;
+  
   if(type == SPDYLAY_SYN_STREAM) {
     struct Request *req;
     int stream_id = frame->syn_stream.stream_id;
@@ -291,6 +304,8 @@ static void on_ctrl_send_callback(spdylay_session *session,
                                   spdylay_frame_type type,
                                   spdylay_frame *frame, void *user_data)
 {
+  (void)user_data;
+  
   char **nv;
   const char *name = NULL;
   int32_t stream_id;
@@ -316,6 +331,8 @@ static void on_ctrl_recv_callback(spdylay_session *session,
                                   spdylay_frame_type type,
                                   spdylay_frame *frame, void *user_data)
 {
+  (void)user_data;
+  
   struct Request *req;
   char **nv;
   const char *name = NULL;
@@ -359,6 +376,8 @@ static void on_stream_close_callback(spdylay_session *session,
                                      spdylay_status_code status_code,
                                      void *user_data)
 {
+  (void)user_data;
+  (void)status_code;
   struct Request *req;
   req = spdylay_session_get_stream_user_data(session, stream_id);
   if(req) {
@@ -381,6 +400,9 @@ static void on_data_chunk_recv_callback(spdylay_session *session, uint8_t flags,
                                         const uint8_t *data, size_t len,
                                         void *user_data)
 {
+  (void)user_data;
+  (void)flags;
+  
   struct Request *req;
   req = spdylay_session_get_stream_user_data(session, stream_id);
   if(req) {
@@ -441,6 +463,8 @@ static int select_next_proto_cb(SSL* ssl,
                                 const unsigned char *in, unsigned int inlen,
                                 void *arg)
 {
+  (void)ssl;
+  
   int rv;
   uint16_t *spdy_proto_version;
   /* spdylay_select_next_protocol() selects SPDY protocol version the
@@ -799,7 +823,7 @@ new_session_callback (void *cls,
 {
 	char ipstr[1024];
 		
-	const struct sockaddr *addr;
+	struct sockaddr *addr;
 	socklen_t addr_len = SPDY_get_remote_addr(session, &addr);	
 	
 	if(!addr_len)
@@ -955,7 +979,7 @@ parentproc(int child)
 	return 0;
 }
 
-int main(int argc, char **argv)
+int main()
 {
 	port = get_port(14123);
 	parent = getpid();
