@@ -29,6 +29,13 @@
 #include <sys/wait.h>
 #include <signal.h>
 
+#ifdef _WIN32
+#ifndef WIN32_LEAN_AND_MEAN
+#define WIN32_LEAN_AND_MEAN 1
+#endif /* !WIN32_LEAN_AND_MEAN */
+#include <windows.h>
+#endif
+
 
 /**
  * A larger loop count will run more random tests --
